---
title: application-setup
url: 'https://docs.danami.com/warden/command-line-interface/application/application-setup'
markdown: 'https://docs.danami.com/warden/command-line-interface/application/application-setup.md'
date: '2026-09-22'
description: 'Configure the network tools settings. warden --task=application-setup --license_key=<string> Option Value Default Description --license_key <string> The extension license key. --autoinstall <1|0> 1 Set to 1 to run the installer and confgure the application. --conten…'
taxonomy:
  category:
    - docs
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Application       application-setup    

# application-setup

Configure the network tools settings.

```
warden --task=application-setup --license_key=<string>

```

| Option | Value | Default | Description |
|---|---|---|---|
| `--license_key` | <string> |  | The extension license key. |
| `--autoinstall` | <1\|0> | 1 | Set to 1 to run the installer and confgure the application. |
| `--content_filter_milter` | <1\|0> | 1 | Set to 1 to install the Amavisd-milter or 0 to not. |
| `--antivirus` | <1\|0> | 1 | Set to 1 to install ClamAV or 0 to not. |
| `--kam` | <1\|0> | 1 | Set to 1 to enable the KAM antispm ruleset or 0 to not. |
| `--maxmind_key` | <string> |  | The MaxMind geolocation license key. See: [How to get a key](https://docs.danami.com/warden/settings/panel-application/geolocation-settings#how-to-get-a-maxmind-license-key) |
| `--abuseipdb_key` | <string> |  | The AbuseIPDB reputation provider API key. See: [How to get a key](https://docs.danami.com/warden/settings/panel-application/network-tools-settings#how-to-get-an-abuseipdb-api-key) |
| `--phishtank_key` | <string> |  | The PhishTank anti-spam phishing API key. See: [How to get a key](https://docs.danami.com/warden/settings/antispam/plugin-settings/phishing#how-to-get-a-phishtank-api-key) |
| `--securiteinfo` | <string> |  | The SecuriteInfo anti-virus signature provider API key. See: [How to get a key](https://docs.danami.com/warden/settings/antivirus/signature-providers#securiteinfo) |
| `--sanesecurity` | <1\|0> | 0 | Set to 1 to enable the SaneSecurity antivirus signature provider. |
| `--urlhaus` | <1\|0> | 0 | Set to 1 to enable the URLhaus antivirus signature provider. |

## Examples

```
// run the installer and configure the application
warden --task=application-setup --license_key=XXXXXXXXXXXXX

// run the installer, configure the application, and set the maxmind API key
warden --task=application-setup --license_key=XXXXXXXXXXXXX --maxmind_key=XXXXXXXXXXXXX
```

 [ ](https://docs.danami.com/warden/command-line-interface/application/application-permissions) [](https://docs.danami.com/warden/command-line-interface/application/application-update)

---

## Navigation

- Previous: [application:permissions](https://docs.danami.com/warden/command-line-interface/application/application-permissions.md)
- Next: [application:update](https://docs.danami.com/warden/command-line-interface/application/application-update.md)
